@@ -26,12 +26,16 @@ class TableauWorkbook:
         if (("applicationPresModel" in cmdResponse["vqlCmdResponse"]["layoutStatus"]) and
                 ("dataDictionary" in cmdResponse["vqlCmdResponse"]["layoutStatus"]["applicationPresModel"])):
             presModel = cmdResponse["vqlCmdResponse"]["layoutStatus"]["applicationPresModel"]
-            dataSegments = presModel["dataDictionary"]["dataSegments"]
-            dataSegmentscp = copy.deepcopy(dataSegments)
-            keys = list(dataSegmentscp.keys())
-            for key in keys:
-                if dataSegmentscp[key] is not None:
-                    self._scraper.dataSegments[key] = dataSegmentscp[key]
+            if "dataSegments" in presModel["dataDictionary"]:
+                dataSegments = presModel["dataDictionary"]["dataSegments"]
+                dataSegmentscp = copy.deepcopy(dataSegments)
+                keys = list(dataSegmentscp.keys())
+                for key in keys:
+                    if dataSegmentscp[key] is not None:
+                        self._scraper.dataSegments[key] = dataSegmentscp[key]
+            else:
+                self._scraper.logger.warning(
+                    f"no data dictionary present in response")
         else:
             self._scraper.logger.warning(
                 f"no data dictionary present in response")
@@ -161,6 +165,30 @@ class TableauWorkbook:
             print("no viewIds found in json info")
         return None
 
+    def getCrossTabData(self, sheetName):
+        r = tableauscraper.api.exportCrosstabServerDialog(self._scraper)
+
+        sheets = [
+            t for t in r["vqlCmdResponse"]["layoutStatus"]["applicationPresModel"]["presentationLayerNotification"][
+                0]["presModelHolder"]["genExportCrosstabOptionsDialogPresModel"]["thumbnailSheetPickerItems"]
+            if t["sheetName"] == sheetName
+        ]
+        if len(sheets) == 0:
+            self._scraper.logger.warning(
+                f"sheet {sheetName} not found in API result")
+            return None
+
+        sheetId = sheets[0]["sheetdocId"]
+        r = tableauscraper.api.exportCrosstabToCsvServer(
+            self._scraper, sheetId)
+        resultKey = r[
+            "vqlCmdResponse"]["layoutStatus"]["applicationPresModel"]["presentationLayerNotification"][0]["presModelHolder"]["genExportFilePresModel"]["resultKey"]
+        r = tableauscraper.api.downloadCrossTabData(self._scraper, resultKey)
+        try:
+            return pd.read_csv(io.StringIO(r), sep='\t')
+        except (ParserError, EmptyDataError):
+            return None
+
     def getStoryPoints(self):
         return tableauscraper.utils.getStoryPointsFromInfo(self._originalInfo)
 
