@@ -99,6 +99,7 @@ def getDownloadableSummaryData(scraper, worksheetName, dashboardName, numRows=20
         files=payload,
         verify=scraper.verify
     )
+    scraper.lastActionTime = time.time()
     return r.json()
 
 
@@ -116,6 +117,7 @@ def getDownloadableUnderlyingData(scraper, worksheetName, dashboardName, numRows
         files=payload,
         verify=scraper.verify
     )
+    scraper.lastActionTime = time.time()
     try:
         return r.json()
     except ValueError:
@@ -136,6 +138,7 @@ def select(scraper, worksheetName, selection):
         files=payload,
         verify=scraper.verify
     )
+    scraper.lastActionTime = time.time()
     try:
         return r.json()
     except (ValueError, JSONDecodeError):
@@ -161,6 +164,7 @@ def filter(scraper, worksheetName, globalFieldName, selection):
         files=payload,
         verify=scraper.verify
     )
+    scraper.lastActionTime = time.time()
     try:
         return r.json()
     except ValueError:
@@ -179,6 +183,7 @@ def setParameterValue(scraper, parameterName, value):
         files=payload,
         verify=scraper.verify
     )
+    scraper.lastActionTime = time.time()
     return r.json()
 
 
@@ -192,9 +197,53 @@ def goToSheet(scraper, windowId):
         files=payload,
         verify=scraper.verify
     )
+    scraper.lastActionTime = time.time()
     return r.json()
 
 
+def exportCrosstabServerDialog(scraper):
+    delayExecution(scraper)
+    payload = (
+        ("thumbnailUris", (None, json.dumps({}))),
+    )
+    r = scraper.session.post(
+        f'{scraper.host}{scraper.tableauData["vizql_root"]}/sessions/{scraper.tableauData["sessionid"]}/commands/tabsrv/export-crosstab-server-dialog',
+        files=payload,
+        verify=scraper.verify
+    )
+    scraper.lastActionTime = time.time()
+    return r.json()
+
+
+def exportCrosstabToCsvServer(scraper, sheetId):
+    delayExecution(scraper)
+    payload = (
+        ("sheetdocId", (None, sheetId)),
+        ("useTabs", (None, "true")),
+        ("sendNotifications", (None, "true")),
+    )
+    r = scraper.session.post(
+        f'{scraper.host}{scraper.tableauData["vizql_root"]}/sessions/{scraper.tableauData["sessionid"]}/commands/tabsrv/export-crosstab-to-csvserver',
+        files=payload,
+        verify=scraper.verify
+    )
+    scraper.lastActionTime = time.time()
+    return r.json()
+
+
+def downloadCrossTabData(scraper, resultKey):
+    r = scraper.session.get(
+        f'{scraper.host}{scraper.tableauData["vizql_root"]}/tempfile/sessions/{scraper.tableauData["sessionid"]}/',
+        params={
+            "key": resultKey,
+            "keepfile": "yes",
+            "attachment": "yes"
+        },
+        verify=scraper.verify)
+    scraper.lastActionTime = time.time()
+    return r.content.decode('utf-16')
+
+
 def setActiveStoryPoint(scraper, storyBoard, storyPointId):
     delayExecution(scraper)
     payload = (
@@ -208,6 +257,7 @@ def setActiveStoryPoint(scraper, storyBoard, storyPointId):
         files=payload,
         verify=scraper.verify
     )
+    scraper.lastActionTime = time.time()
     return r.json()
 
 
@@ -225,6 +275,7 @@ def levelDrill(scraper, worksheetName, drillDown, position=0):
         files=payload,
         verify=scraper.verify
     )
+    scraper.lastActionTime = time.time()
     return r.json()
 
 
